%global jarname commons-jexl
%global compatver 2.1.0

Name:           apache-%{jarname}
Version:        2.1.1
Release:        %mkrel 16
Summary:        Java Expression Language (JEXL)

Group:          Development/Java
License:        ASL 2.0
URL:            http://commons.apache.org/jexl
Source0:        http://www.apache.org/dist/commons/jexl/source/%{jarname}-%{version}-src.tar.gz
# Patch to fix test failure with junit 4.11
Patch0:         001-Fix-tests.patch
# Fix javadoc build
Patch1:         apache-commons-jexl-javadoc.patch

BuildRequires:  maven-local
BuildRequires:  javacc-maven-plugin

BuildArch:      noarch

Provides:       %{jarname} = %{version}-%{release}

%description
Java Expression Language (JEXL) is an expression language engine which can be
embedded in applications and frameworks.  JEXL is inspired by Jakarta Velocity
and the Expression Language defined in the JavaServer Pages Standard Tag
Library version 1.1 (JSTL) and JavaServer Pages version 2.0 (JSP).  While
inspired by JSTL EL, it must be noted that JEXL is not a compatible
implementation of EL as defined in JSTL 1.1 (JSR-052) or JSP 2.0 (JSR-152).
For a compatible implementation of these specifications, see the Commons EL
project.

JEXL attempts to bring some of the lessons learned by the Velocity community
about expression languages in templating to a wider audience.  Commons Jelly
needed Velocity-ish method access, it just had to have it.


%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       jpackage-utils
Provides:       %{jarname}-javadoc = %{version}-%{release}

%description javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q -n %{jarname}-%{version}-src
%patch0 -p1 -b .test
%patch1 -p1 -b .javadoc
# Java 1.6 contains bsf 3.0, so we don't need the dependency in the pom.xml file
%pom_remove_dep org.apache.bsf:bsf-api
find \( -name '*.jar' -o -name '*.class' \) -delete
# Fix line endings
find -name '*.txt' -exec sed -i 's/\r//' '{}' +

# Drop "-SNAPSHOT" from version
%pom_xpath_set "pom:project/pom:version" %{compatver} jexl2-compat
%pom_xpath_set "pom:dependency[pom:artifactId='commons-jexl']/pom:version" %{version} jexl2-compat

echo "
<project>
  <modelVersion>4.0.0</modelVersion>
  <groupId>org.fedoraproject</groupId>
  <artifactId>commons-jexl-aggegator</artifactId>
  <version>%{version}</version>
  <packaging>pom</packaging>
  <modules>
    <module>.</module>
    <module>jexl2-compat</module>
  </modules>
</project>" >>aggregator-pom.xml
%mvn_package :commons-jexl-aggegator __noinstall

%build
%mvn_build -- -f aggregator-pom.xml

%install
%mvn_install


%files -f .mfiles
%doc LICENSE.txt NOTICE.txt RELEASE-NOTES.txt
%{_javadir}/%{name}

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt





%changelog
* Wed Mar 02 2016 neoclust <neoclust> 2.1.1-16.mga6
+ Revision: 982094
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 2.1.1-15.mga6
+ Revision: 975434
- First rebuild of the java stack
- sync package apache-commons-jexl with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.1.1-11.mga5
+ Revision: 746018
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.1-10.mga5
+ Revision: 677811
- Mageia 5 Mass Rebuild

* Tue Nov 26 2013 dmorgan <dmorgan> 2.1.1-9.mga4
+ Revision: 553588
- Fix BuildRequires

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Thu Jul 11 2013 dmorgan <dmorgan> 2.1.1-7.mga4
+ Revision: 453198
- Build with xmvn
- New version

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 28 2011 dmorgan <dmorgan> 2.0.1-6.mga2
+ Revision: 188460
- Packaging fixes
- New maven macro for depmaps (include a compat depmap) #745118

* Wed Apr 27 2011 dmorgan <dmorgan> 2.0.1-5.mga1
+ Revision: 92237
- Rebuild after bootstrapping
- imported package apache-commons-jexl


* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 6 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-3
- Use BR apache-commons-parent

* Tue Jul 13 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-2
- Add license to javadoc package

* Wed May 26 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-1
- Update to 2.0.1
- Require Java 1.6 or greater
- Drop language level patch
- Add patch to remove bsf-api 3.0 dependency from pom.xml as this is provided
  by Java 1.6
- Fix depmap group id

* Sat Jan 9 2010 Orion Poplawski <orion@cora.nwra.com> - 1.1-3
- Drop gcj support
- Fix javadoc group
- Bump java levels in pom.xml

* Thu Jan 7 2010 Orion Poplawski <orion@cora.nwra.com> - 1.1-2
- Rename to apache-commons-jexl

* Tue Oct 27 2009 Orion Poplawski <orion@cora.nwra.com> - 1.1-1
- Initial Fedora Package
